@@ -1,5 +1,6 @@
 from loralogger.handlers import LogToESHandler
-from loralogger.loggers import LoggerInstances, LoraLogger
+from loralogger.instances import LoggerInstances
+from loralogger.loggers import LoraLogger
 from loralogger.producer import worker
 
 __all__ = ("LogToESHandler", "LoggerInstances", "LoraLogger")
