@@ -6,6 +6,7 @@ from dataclasses import dataclass
 class Config:
     broker_url: str
     result_backend: str
+    sentinel_mode: bool
 
 
 class ConfigBuilder:
@@ -13,12 +14,14 @@ class ConfigBuilder:
 
     broker_url: str = "amqp://rabbitmq:rabbitmq@localhost:5672/"
     result_backend: str = "redis://localhost:6379"
+    sentinel_mode: bool = False
 
     @classmethod
     def __build_config(cls) -> Config:
         return Config(
             broker_url=cls.broker_url,
             result_backend=cls.result_backend,
+            sentinel_mode=cls.sentinel_mode,
         )
 
     @classmethod
@@ -34,6 +37,7 @@ class ConfigBuilder:
 
         redis_host = os.getenv("REDIS_HOST")
         redis_port = os.getenv("REDIS_PORT")
+        sentinel_mode = True if os.getenv("REDIS_SENTINEL", "False") == "True" else False  # type: ignore
 
         if None in [
             amqp_broker,
@@ -46,6 +50,9 @@ class ConfigBuilder:
             return cls.local()
 
         cls.broker_url = f"amqp://{amqp_user}:{amqp_pass}@{amqp_broker}:{amqp_port}/"
-        cls.result_backend = f"redis://{redis_host}:{redis_port}"
+        cls.result_backend = (
+            f"{'sentinel' if sentinel_mode else 'redis'}://{redis_host}:{redis_port}"
+        )
+        cls.sentinel_mode = sentinel_mode
 
         return cls.__build_config()
