@@ -2,13 +2,17 @@ from logging import LogRecord, Handler
 import logging
 
 from loralogger.utils import separate_log_data
+from loralogger.instances import LoggerInstances
 
 
 class LogToESHandler(Handler):
-    def __init__(self, label: str) -> None:
+    def __init__(self, label: LoggerInstances) -> None:
         super().__init__()
 
-        self.label = label
+        if not LoggerInstances.has_value(label):
+            raise TypeError("Not a valid LoggerInstance label")
+
+        self.label = label.value
 
     def write_log(self, level: str, log_content: dict, extra_data: dict) -> None:
         from loralogger.producer import worker
