@@ -21,5 +21,9 @@ try:
         broker_url=config.broker_url,
         result_backend=config.result_backend,
     )
+
+    if config.sentinel_mode:
+        worker.conf.result_backend_transport_options = {"master_name": "redismaster"}
+
 except Exception:
     logging.exception("Cannot initialize producer")
